summaryrefslogtreecommitdiff
path: root/program.h
diff options
context:
space:
mode:
Diffstat (limited to 'program.h')
-rw-r--r--program.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/program.h b/program.h
index 35f401696a..df903edc95 100644
--- a/program.h
+++ b/program.h
@@ -24,9 +24,9 @@
#include <GL/gl.h>
/**
* Based on gl_program in Mesa's mtypes.h.
*/
-struct glsl_program {
+struct glsl_shader {
GLenum Type;
GLuint Name;
GLint RefCount;
@@ -24,9 +24,9 @@
#include <GL/gl.h>
/**
- * Based on gl_program in Mesa's mtypes.h.
+ * Based on gl_shader in Mesa's mtypes.h.
*/